# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.encrypted_app_ticket_pb2 as encrypted__app__ticket__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n steammessages_clientserver.proto\x1a\x18steammessages_base.proto\x1a\x1a\x65ncrypted_app_ticket.proto\"j\n\"CMsgClientRegisterAuthTicketWithCM\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\x12\x1a\n\x12\x63lient_instance_id\x18\x04 \x01(\x04\"\xd1\x01\n\x1c\x43MsgClientTicketAuthComplete\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x65state\x18\x03 \x01(\r\x12\x1e\n\x16\x65\x61uth_session_response\x18\x04 \x01(\r\x12\x19\n\x11\x44\x45PRECATED_ticket\x18\x05 \x01(\x0c\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x17\n\x0fticket_sequence\x18\x07 \x01(\r\x12\x16\n\x0eowner_steam_id\x18\x08 \x01(\x06\"\x80\x01\n\x10\x43MsgClientCMList\x12\x14\n\x0c\x63m_addresses\x18\x01 \x03(\r\x12\x10\n\x08\x63m_ports\x18\x02 \x03(\r\x12\x1e\n\x16\x63m_websocket_addresses\x18\x03 \x03(\t\x12$\n\x1cpercent_default_to_websocket\x18\x04 \x01(\r\"\xa3\x01\n\x1b\x43MsgClientP2PConnectionInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x11\n\tcandidate\x18\x04 \x01(\x0c\x12 \n\x18legacy_connection_id_src\x18\x05 \x01(\x06\x12\x12\n\nrendezvous\x18\x06 \x01(\x0c\"\xc3\x01\n\x1f\x43MsgClientP2PConnectionFailInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1a\n\x12\x65p2p_session_error\x18\x04 \x01(\r\x12\x1a\n\x12\x63onnection_id_dest\x18\x05 \x01(\x06\x12\x14\n\x0c\x63lose_reason\x18\x07 \x01(\r\x12\x15\n\rclose_message\x18\x08 \x01(\t\"C\n\x1f\x43MsgClientNetworkingCertRequest\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"V\n\x1d\x43MsgClientNetworkingCertReply\x12\x0c\n\x04\x63\x65rt\x18\x04 \x01(\x0c\x12\x11\n\tca_key_id\x18\x05 \x01(\x06\x12\x14\n\x0c\x63\x61_signature\x18\x06 \x01(\x0c\"7\n%CMsgClientNetworkingMobileCertRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\";\n#CMsgClientNetworkingMobileCertReply\x12\x14\n\x0c\x65ncoded_cert\x18\x01 \x01(\t\"1\n\x1f\x43MsgClientGetAppOwnershipTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"]\n\'CMsgClientGetAppOwnershipTicketResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\"\'\n\x16\x43MsgClientSessionToken\x12\r\n\x05token\x18\x01 \x01(\x04\"M\n\x1b\x43MsgClientGameConnectTokens\x12\x1e\n\x12max_tokens_to_keep\x18\x01 \x01(\r:\x02\x31\x30\x12\x0e\n\x06tokens\x18\x02 \x03(\x0c\"\x85\x08\n\x15\x43MsgClientGamesPlayed\x12\x37\n\x0cgames_played\x18\x01 \x03(\x0b\x32!.CMsgClientGamesPlayed.GamePlayed\x12\x16\n\x0e\x63lient_os_type\x18\x02 \x01(\r\x12\x1d\n\x15\x63loud_gaming_platform\x18\x03 \x01(\r\x12\x1f\n\x17recent_reauthentication\x18\x04 \x01(\x08\x1a\xda\x06\n\nGamePlayed\x12\x13\n\x0bsteam_id_gs\x18\x01 \x01(\x04\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x11\n\tis_secure\x18\x05 \x01(\x08\x12\r\n\x05token\x18\x06 \x01(\x0c\x12\x17\n\x0fgame_extra_info\x18\x07 \x01(\t\x12\x16\n\x0egame_data_blob\x18\x08 \x01(\x0c\x12\x12\n\nprocess_id\x18\t \x01(\r\x12\x1d\n\x15streaming_provider_id\x18\n \x01(\r\x12\x12\n\ngame_flags\x18\x0b \x01(\r\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x15\n\rvr_hmd_vendor\x18\r \x01(\t\x12\x14\n\x0cvr_hmd_model\x18\x0e \x01(\t\x12\x1d\n\x12launch_option_type\x18\x0f \x01(\r:\x01\x30\x12#\n\x17primary_controller_type\x18\x10 \x01(\x05:\x02-1\x12\'\n\x1fprimary_steam_controller_serial\x18\x11 \x01(\t\x12\'\n\x1ctotal_steam_controller_count\x18\x12 \x01(\r:\x01\x30\x12+\n total_non_steam_controller_count\x18\x13 \x01(\r:\x01\x30\x12&\n\x1b\x63ontroller_workshop_file_id\x18\x14 \x01(\x04:\x01\x30\x12\x18\n\rlaunch_source\x18\x15 \x01(\r:\x01\x30\x12\x16\n\x0evr_hmd_runtime\x18\x16 \x01(\r\x12\'\n\x0fgame_ip_address\x18\x17 \x01(\x0b\x32\x0e.CMsgIPAddress\x12%\n\x1a\x63ontroller_connection_type\x18\x18 \x01(\r:\x01\x30\x12\x18\n\x10game_os_platform\x18\x19 \x01(\x05\x12\x15\n\rgame_build_id\x18\x1a \x01(\r\x12\x19\n\x0e\x63ompat_tool_id\x18\x1b \x01(\r:\x01\x30\x12\x17\n\x0f\x63ompat_tool_cmd\x18\x1c \x01(\t\x12\x1c\n\x14\x63ompat_tool_build_id\x18\x1d \x01(\r\x12\x11\n\tbeta_name\x18\x1e \x01(\t\x12\x13\n\x0b\x64lc_context\x18\x1f \x01(\r\"9\n\rCMsgGSApprove\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0eowner_steam_id\x18\x02 \x01(\x06\"I\n\nCMsgGSDeny\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65ny_string\x18\x03 \x01(\t\"4\n\nCMsgGSKick\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\"\xb6\x01\n\x12\x43MsgClientAuthList\x12\x13\n\x0btokens_left\x18\x01 \x01(\r\x12\x18\n\x10last_request_seq\x18\x02 \x01(\r\x12$\n\x1clast_request_seq_from_server\x18\x03 \x01(\r\x12 \n\x07tickets\x18\x04 \x03(\x0b\x32\x0f.CMsgAuthTicket\x12\x0f\n\x07\x61pp_ids\x18\x05 \x03(\r\x12\x18\n\x10message_sequence\x18\x06 \x01(\r\"V\n\x15\x43MsgClientAuthListAck\x12\x12\n\nticket_crc\x18\x01 \x03(\r\x12\x0f\n\x07\x61pp_ids\x18\x02 \x03(\r\x12\x18\n\x10message_sequence\x18\x03 \x01(\r\"\x8e\x04\n\x15\x43MsgClientLicenseList\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x30\n\x08licenses\x18\x02 \x03(\x0b\x32\x1e.CMsgClientLicenseList.License\x1a\xae\x03\n\x07License\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x14\n\x0ctime_created\x18\x02 \x01(\x07\x12\x19\n\x11time_next_process\x18\x03 \x01(\x07\x12\x14\n\x0cminute_limit\x18\x04 \x01(\x05\x12\x14\n\x0cminutes_used\x18\x05 \x01(\x05\x12\x16\n\x0epayment_method\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x1d\n\x15purchase_country_code\x18\x08 \x01(\t\x12\x14\n\x0clicense_type\x18\t \x01(\r\x12\x16\n\x0eterritory_code\x18\n \x01(\x05\x12\x15\n\rchange_number\x18\x0b \x01(\x05\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x16\n\x0einitial_period\x18\r \x01(\r\x12\x19\n\x11initial_time_unit\x18\x0e \x01(\r\x12\x16\n\x0erenewal_period\x18\x0f \x01(\r\x12\x19\n\x11renewal_time_unit\x18\x10 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x11 \x01(\x04\x12\x19\n\x11master_package_id\x18\x12 \x01(\r\"\xaa\x01\n\x1a\x43MsgClientIsLimitedAccount\x12\x1b\n\x13\x62is_limited_account\x18\x01 \x01(\x08\x12\x1c\n\x14\x62is_community_banned\x18\x02 \x01(\x08\x12\x1a\n\x12\x62is_locked_account\x18\x03 \x01(\x08\x12\x35\n-bis_limited_account_allowed_to_invite_friends\x18\x04 \x01(\x08\"\xa7\x01\n\x1e\x43MsgClientRequestedClientStats\x12\x42\n\rstats_to_send\x18\x01 \x03(\x0b\x32+.CMsgClientRequestedClientStats.StatsToSend\x1a\x41\n\x0bStatsToSend\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x1d\n\x15stat_aggregate_method\x18\x02 \x01(\r\"\xc0\x01\n\x0f\x43MsgClientStat2\x12\x30\n\x0bstat_detail\x18\x01 \x03(\x0b\x32\x1b.CMsgClientStat2.StatDetail\x1a{\n\nStatDetail\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x10\n\x08ll_value\x18\x02 \x01(\x03\x12\x13\n\x0btime_of_day\x18\x03 \x01(\r\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x05 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\r\"r\n\x16\x43MsgClientInviteToGame\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x16\n\x0e\x63onnect_string\x18\x03 \x01(\t\x12\x13\n\x0bremote_play\x18\x04 \x01(\t\"\xb9\x01\n\x14\x43MsgClientChatInvite\x12\x18\n\x10steam_id_invited\x18\x01 \x01(\x06\x12\x15\n\rsteam_id_chat\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_patron\x18\x03 \x01(\x06\x12\x15\n\rchatroom_type\x18\x04 \x01(\x05\x12\x1c\n\x14steam_id_friend_chat\x18\x05 \x01(\x06\x12\x11\n\tchat_name\x18\x06 \x01(\t\x12\x0f\n\x07game_id\x18\x07 \x01(\x06\"\x96\t\n\x19\x43MsgClientConnectionStats\x12;\n\x0bstats_logon\x18\x01 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_Logon\x12;\n\x0bstats_vconn\x18\x02 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_VConn\x1a\xd3\x02\n\x0bStats_Logon\x12\x18\n\x10\x63onnect_attempts\x18\x01 \x01(\x05\x12\x19\n\x11\x63onnect_successes\x18\x02 \x01(\x05\x12\x18\n\x10\x63onnect_failures\x18\x03 \x01(\x05\x12\x1b\n\x13\x63onnections_dropped\x18\x04 \x01(\x05\x12\x17\n\x0fseconds_running\x18\x05 \x01(\r\x12\x1c\n\x14msec_tologonthistime\x18\x06 \x01(\r\x12\x15\n\rcount_bad_cms\x18\x07 \x01(\r\x12\x1b\n\x13no_udp_connectivity\x18\x08 \x01(\x08\x12\x1b\n\x13no_tcp_connectivity\x18\t \x01(\x08\x12%\n\x1dno_websocket_443_connectivity\x18\n \x01(\x08\x12)\n!no_websocket_non_443_connectivity\x18\x0b \x01(\x08\x1aq\n\tStats_UDP\x12\x11\n\tpkts_sent\x18\x01 \x01(\x04\x12\x12\n\nbytes_sent\x18\x02 \x01(\x04\x12\x11\n\tpkts_recv\x18\x03 \x01(\x04\x12\x16\n\x0epkts_processed\x18\x04 \x01(\x04\x12\x12\n\nbytes_recv\x18\x05 \x01(\x04\x1a\xb5\x04\n\x0bStats_VConn\x12\x17\n\x0f\x63onnections_udp\x18\x01 \x01(\r\x12\x17\n\x0f\x63onnections_tcp\x18\x02 \x01(\r\x12\x37\n\tstats_udp\x18\x03 \x01(\x0b\x32$.CMsgClientConnectionStats.Stats_UDP\x12\x16\n\x0epkts_abandoned\x18\x04 \x01(\x04\x12\x19\n\x11\x63onn_req_received\x18\x05 \x01(\x04\x12\x13\n\x0bpkts_resent\x18\x06 \x01(\x04\x12\x11\n\tmsgs_sent\x18\x07 \x01(\x04\x12\x18\n\x10msgs_sent_failed\x18\x08 \x01(\x04\x12\x11\n\tmsgs_recv\x18\t \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_sent\x18\n \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_recv\x18\x0b \x01(\x04\x12\x15\n\rbad_pkts_recv\x18\x0c \x01(\x04\x12\x1e\n\x16unknown_conn_pkts_recv\x18\r \x01(\x04\x12\x18\n\x10missed_pkts_recv\x18\x0e \x01(\x04\x12\x15\n\rdup_pkts_recv\x18\x0f \x01(\x04\x12!\n\x19\x66\x61iled_connect_challenges\x18\x10 \x01(\x04\x12\x1d\n\x15micro_sec_avg_latency\x18\x11 \x01(\r\x12\x1d\n\x15micro_sec_min_latency\x18\x12 \x01(\r\x12\x1d\n\x15micro_sec_max_latency\x18\x13 \x01(\r\x12\x1b\n\x13mem_pool_msg_in_use\x18\x14 \x01(\r\"\xd2\x01\n\x1a\x43MsgClientServersAvailable\x12R\n\x16server_types_available\x18\x01 \x03(\x0b\x32\x32.CMsgClientServersAvailable.Server_Types_Available\x12%\n\x1dserver_type_for_auth_services\x18\x02 \x01(\r\x1a\x39\n\x16Server_Types_Available\x12\x0e\n\x06server\x18\x01 \x01(\r\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\"?\n$CMsgClientReportOverlayDetourFailure\x12\x17\n\x0f\x66\x61ilure_strings\x18\x01 \x03(\t\"G\n#CMsgClientRequestEncryptedAppTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08userdata\x18\x02 \x01(\x0c\"\x84\x01\n+CMsgClientRequestEncryptedAppTicketResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x31\n\x14\x65ncrypted_app_ticket\x18\x03 \x01(\x0b\x32\x13.EncryptedAppTicket\"\xb5\x01\n\x1a\x43MsgClientWalletInfoUpdate\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x17\n\x0f\x62\x61lance_delayed\x18\x04 \x01(\x05\x12\x17\n\tbalance64\x18\x05 \x01(\x03\x42\x04\xa0\xb6\x18\x01\x12\x1f\n\x11\x62\x61lance64_delayed\x18\x06 \x01(\x03\x42\x04\xa0\xb6\x18\x01\x12\r\n\x05realm\x18\x07 \x01(\x05\"3\n\x1b\x43MsgClientAMGetClanOfficers\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\"f\n#CMsgClientAMGetClanOfficersResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x14\n\x0csteamid_clan\x18\x02 \x01(\x06\x12\x15\n\rofficer_count\x18\x03 \x01(\x05\"\x90\x01\n!CMsgClientAMGetPersonaNameHistory\x12\x10\n\x08id_count\x18\x01 \x01(\x05\x12:\n\x03Ids\x18\x02 \x03(\x0b\x32-.CMsgClientAMGetPersonaNameHistory.IdInstance\x1a\x1d\n\nIdInstance\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xc3\x02\n)CMsgClientAMGetPersonaNameHistoryResponse\x12O\n\tresponses\x18\x02 \x03(\x0b\x32<.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance\x1a\xc4\x01\n\x11NameTableInstance\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12X\n\x05names\x18\x03 \x03(\x0b\x32I.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance\x1a\x30\n\x0cNameInstance\x12\x12\n\nname_since\x18\x01 \x01(\x07\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x1e\x43MsgClientDeregisterWithServer\x12\x13\n\x0b\x65servertype\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\xab\x04\n\x13\x43MsgClientClanState\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\x12\x1a\n\x12\x63lan_account_flags\x18\x03 \x01(\r\x12\x30\n\tname_info\x18\x04 \x01(\x0b\x32\x1d.CMsgClientClanState.NameInfo\x12\x34\n\x0buser_counts\x18\x05 \x01(\x0b\x32\x1f.CMsgClientClanState.UserCounts\x12*\n\x06\x65vents\x18\x06 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x31\n\rannouncements\x18\x07 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x19\n\x11\x63hat_room_private\x18\x08 \x01(\x08\x1a\x31\n\x08NameInfo\x12\x11\n\tclan_name\x18\x01 \x01(\t\x12\x12\n\nsha_avatar\x18\x02 \x01(\x0c\x1ak\n\nUserCounts\x12\x0f\n\x07members\x18\x01 \x01(\r\x12\x0e\n\x06online\x18\x02 \x01(\r\x12\x10\n\x08\x63hatting\x18\x03 \x01(\r\x12\x0f\n\x07in_game\x18\x04 \x01(\r\x12\x19\n\x11\x63hat_room_members\x18\x05 \x01(\r\x1a`\n\x05\x45vent\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x12\n\nevent_time\x18\x02 \x01(\r\x12\x10\n\x08headline\x18\x03 \x01(\t\x12\x0f\n\x07game_id\x18\x04 \x01(\x06\x12\x13\n\x0bjust_posted\x18\x05 \x01(\x08\x42\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,encrypted__app__ticket__pb2.DESCRIPTOR,])




_CMSGCLIENTREGISTERAUTHTICKETWITHCM = _descriptor.Descriptor(
  name='CMsgClientRegisterAuthTicketWithCM',
  full_name='CMsgClientRegisterAuthTicketWithCM',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientRegisterAuthTicketWithCM.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgClientRegisterAuthTicketWithCM.ticket', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_instance_id', full_name='CMsgClientRegisterAuthTicketWithCM.client_instance_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=196,
)


_CMSGCLIENTTICKETAUTHCOMPLETE = _descriptor.Descriptor(
  name='CMsgClientTicketAuthComplete',
  full_name='CMsgClientTicketAuthComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientTicketAuthComplete.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientTicketAuthComplete.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estate', full_name='CMsgClientTicketAuthComplete.estate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eauth_session_response', full_name='CMsgClientTicketAuthComplete.eauth_session_response', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='DEPRECATED_ticket', full_name='CMsgClientTicketAuthComplete.DEPRECATED_ticket', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket_crc', full_name='CMsgClientTicketAuthComplete.ticket_crc', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket_sequence', full_name='CMsgClientTicketAuthComplete.ticket_sequence', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_steam_id', full_name='CMsgClientTicketAuthComplete.owner_steam_id', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=408,
)


_CMSGCLIENTCMLIST = _descriptor.Descriptor(
  name='CMsgClientCMList',
  full_name='CMsgClientCMList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cm_addresses', full_name='CMsgClientCMList.cm_addresses', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cm_ports', full_name='CMsgClientCMList.cm_ports', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cm_websocket_addresses', full_name='CMsgClientCMList.cm_websocket_addresses', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_default_to_websocket', full_name='CMsgClientCMList.percent_default_to_websocket', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=539,
)


_CMSGCLIENTP2PCONNECTIONINFO = _descriptor.Descriptor(
  name='CMsgClientP2PConnectionInfo',
  full_name='CMsgClientP2PConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientP2PConnectionInfo.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientP2PConnectionInfo.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientP2PConnectionInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CMsgClientP2PConnectionInfo.candidate', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legacy_connection_id_src', full_name='CMsgClientP2PConnectionInfo.legacy_connection_id_src', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rendezvous', full_name='CMsgClientP2PConnectionInfo.rendezvous', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=705,
)


_CMSGCLIENTP2PCONNECTIONFAILINFO = _descriptor.Descriptor(
  name='CMsgClientP2PConnectionFailInfo',
  full_name='CMsgClientP2PConnectionFailInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientP2PConnectionFailInfo.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientP2PConnectionFailInfo.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientP2PConnectionFailInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ep2p_session_error', full_name='CMsgClientP2PConnectionFailInfo.ep2p_session_error', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id_dest', full_name='CMsgClientP2PConnectionFailInfo.connection_id_dest', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_reason', full_name='CMsgClientP2PConnectionFailInfo.close_reason', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_message', full_name='CMsgClientP2PConnectionFailInfo.close_message', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=903,
)


_CMSGCLIENTNETWORKINGCERTREQUEST = _descriptor.Descriptor(
  name='CMsgClientNetworkingCertRequest',
  full_name='CMsgClientNetworkingCertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_data', full_name='CMsgClientNetworkingCertRequest.key_data', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientNetworkingCertRequest.app_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=972,
)


_CMSGCLIENTNETWORKINGCERTREPLY = _descriptor.Descriptor(
  name='CMsgClientNetworkingCertReply',
  full_name='CMsgClientNetworkingCertReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cert', full_name='CMsgClientNetworkingCertReply.cert', index=0,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_key_id', full_name='CMsgClientNetworkingCertReply.ca_key_id', index=1,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_signature', full_name='CMsgClientNetworkingCertReply.ca_signature', index=2,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=1060,
)


_CMSGCLIENTNETWORKINGMOBILECERTREQUEST = _descriptor.Descriptor(
  name='CMsgClientNetworkingMobileCertRequest',
  full_name='CMsgClientNetworkingMobileCertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientNetworkingMobileCertRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1117,
)


_CMSGCLIENTNETWORKINGMOBILECERTREPLY = _descriptor.Descriptor(
  name='CMsgClientNetworkingMobileCertReply',
  full_name='CMsgClientNetworkingMobileCertReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoded_cert', full_name='CMsgClientNetworkingMobileCertReply.encoded_cert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1119,
  serialized_end=1178,
)


_CMSGCLIENTGETAPPOWNERSHIPTICKET = _descriptor.Descriptor(
  name='CMsgClientGetAppOwnershipTicket',
  full_name='CMsgClientGetAppOwnershipTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetAppOwnershipTicket.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1229,
)


_CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetAppOwnershipTicketResponse',
  full_name='CMsgClientGetAppOwnershipTicketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetAppOwnershipTicketResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetAppOwnershipTicketResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgClientGetAppOwnershipTicketResponse.ticket', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1324,
)


_CMSGCLIENTSESSIONTOKEN = _descriptor.Descriptor(
  name='CMsgClientSessionToken',
  full_name='CMsgClientSessionToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientSessionToken.token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1365,
)


_CMSGCLIENTGAMECONNECTTOKENS = _descriptor.Descriptor(
  name='CMsgClientGameConnectTokens',
  full_name='CMsgClientGameConnectTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens_to_keep', full_name='CMsgClientGameConnectTokens.max_tokens_to_keep', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CMsgClientGameConnectTokens.tokens', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1444,
)


_CMSGCLIENTGAMESPLAYED_GAMEPLAYED = _descriptor.Descriptor(
  name='GamePlayed',
  full_name='CMsgClientGamesPlayed.GamePlayed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_gs', full_name='CMsgClientGamesPlayed.GamePlayed.steam_id_gs', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGamesPlayed.GamePlayed.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_game_ip_address', full_name='CMsgClientGamesPlayed.GamePlayed.deprecated_game_ip_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgClientGamesPlayed.GamePlayed.game_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_secure', full_name='CMsgClientGamesPlayed.GamePlayed.is_secure', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientGamesPlayed.GamePlayed.token', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_extra_info', full_name='CMsgClientGamesPlayed.GamePlayed.game_extra_info', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_data_blob', full_name='CMsgClientGamesPlayed.GamePlayed.game_data_blob', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='CMsgClientGamesPlayed.GamePlayed.process_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_provider_id', full_name='CMsgClientGamesPlayed.GamePlayed.streaming_provider_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_flags', full_name='CMsgClientGamesPlayed.GamePlayed.game_flags', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientGamesPlayed.GamePlayed.owner_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vr_hmd_vendor', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_vendor', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vr_hmd_model', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_model', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launch_option_type', full_name='CMsgClientGamesPlayed.GamePlayed.launch_option_type', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_controller_type', full_name='CMsgClientGamesPlayed.GamePlayed.primary_controller_type', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_steam_controller_serial', full_name='CMsgClientGamesPlayed.GamePlayed.primary_steam_controller_serial', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_steam_controller_count', full_name='CMsgClientGamesPlayed.GamePlayed.total_steam_controller_count', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_non_steam_controller_count', full_name='CMsgClientGamesPlayed.GamePlayed.total_non_steam_controller_count', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_workshop_file_id', full_name='CMsgClientGamesPlayed.GamePlayed.controller_workshop_file_id', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launch_source', full_name='CMsgClientGamesPlayed.GamePlayed.launch_source', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vr_hmd_runtime', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_runtime', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_ip_address', full_name='CMsgClientGamesPlayed.GamePlayed.game_ip_address', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_connection_type', full_name='CMsgClientGamesPlayed.GamePlayed.controller_connection_type', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_os_platform', full_name='CMsgClientGamesPlayed.GamePlayed.game_os_platform', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_build_id', full_name='CMsgClientGamesPlayed.GamePlayed.game_build_id', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compat_tool_id', full_name='CMsgClientGamesPlayed.GamePlayed.compat_tool_id', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compat_tool_cmd', full_name='CMsgClientGamesPlayed.GamePlayed.compat_tool_cmd', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compat_tool_build_id', full_name='CMsgClientGamesPlayed.GamePlayed.compat_tool_build_id', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta_name', full_name='CMsgClientGamesPlayed.GamePlayed.beta_name', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dlc_context', full_name='CMsgClientGamesPlayed.GamePlayed.dlc_context', index=30,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=2476,
)

_CMSGCLIENTGAMESPLAYED = _descriptor.Descriptor(
  name='CMsgClientGamesPlayed',
  full_name='CMsgClientGamesPlayed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='games_played', full_name='CMsgClientGamesPlayed.games_played', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_os_type', full_name='CMsgClientGamesPlayed.client_os_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_gaming_platform', full_name='CMsgClientGamesPlayed.cloud_gaming_platform', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recent_reauthentication', full_name='CMsgClientGamesPlayed.recent_reauthentication', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGAMESPLAYED_GAMEPLAYED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=2476,
)


_CMSGGSAPPROVE = _descriptor.Descriptor(
  name='CMsgGSApprove',
  full_name='CMsgGSApprove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSApprove.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_steam_id', full_name='CMsgGSApprove.owner_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2478,
  serialized_end=2535,
)


_CMSGGSDENY = _descriptor.Descriptor(
  name='CMsgGSDeny',
  full_name='CMsgGSDeny',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSDeny.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edeny_reason', full_name='CMsgGSDeny.edeny_reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_string', full_name='CMsgGSDeny.deny_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2537,
  serialized_end=2610,
)


_CMSGGSKICK = _descriptor.Descriptor(
  name='CMsgGSKick',
  full_name='CMsgGSKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSKick.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edeny_reason', full_name='CMsgGSKick.edeny_reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2612,
  serialized_end=2664,
)


_CMSGCLIENTAUTHLIST = _descriptor.Descriptor(
  name='CMsgClientAuthList',
  full_name='CMsgClientAuthList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens_left', full_name='CMsgClientAuthList.tokens_left', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_request_seq', full_name='CMsgClientAuthList.last_request_seq', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_request_seq_from_server', full_name='CMsgClientAuthList.last_request_seq_from_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tickets', full_name='CMsgClientAuthList.tickets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='CMsgClientAuthList.app_ids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_sequence', full_name='CMsgClientAuthList.message_sequence', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2667,
  serialized_end=2849,
)


_CMSGCLIENTAUTHLISTACK = _descriptor.Descriptor(
  name='CMsgClientAuthListAck',
  full_name='CMsgClientAuthListAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_crc', full_name='CMsgClientAuthListAck.ticket_crc', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='CMsgClientAuthListAck.app_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_sequence', full_name='CMsgClientAuthListAck.message_sequence', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2851,
  serialized_end=2937,
)


_CMSGCLIENTLICENSELIST_LICENSE = _descriptor.Descriptor(
  name='License',
  full_name='CMsgClientLicenseList.License',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_id', full_name='CMsgClientLicenseList.License.package_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgClientLicenseList.License.time_created', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_next_process', full_name='CMsgClientLicenseList.License.time_next_process', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute_limit', full_name='CMsgClientLicenseList.License.minute_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minutes_used', full_name='CMsgClientLicenseList.License.minutes_used', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_method', full_name='CMsgClientLicenseList.License.payment_method', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgClientLicenseList.License.flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purchase_country_code', full_name='CMsgClientLicenseList.License.purchase_country_code', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license_type', full_name='CMsgClientLicenseList.License.license_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='territory_code', full_name='CMsgClientLicenseList.License.territory_code', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientLicenseList.License.change_number', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientLicenseList.License.owner_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_period', full_name='CMsgClientLicenseList.License.initial_period', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_time_unit', full_name='CMsgClientLicenseList.License.initial_time_unit', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='renewal_period', full_name='CMsgClientLicenseList.License.renewal_period', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='renewal_time_unit', full_name='CMsgClientLicenseList.License.renewal_time_unit', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientLicenseList.License.access_token', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_package_id', full_name='CMsgClientLicenseList.License.master_package_id', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3466,
)

_CMSGCLIENTLICENSELIST = _descriptor.Descriptor(
  name='CMsgClientLicenseList',
  full_name='CMsgClientLicenseList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLicenseList.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='licenses', full_name='CMsgClientLicenseList.licenses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTLICENSELIST_LICENSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2940,
  serialized_end=3466,
)


_CMSGCLIENTISLIMITEDACCOUNT = _descriptor.Descriptor(
  name='CMsgClientIsLimitedAccount',
  full_name='CMsgClientIsLimitedAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bis_limited_account', full_name='CMsgClientIsLimitedAccount.bis_limited_account', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bis_community_banned', full_name='CMsgClientIsLimitedAccount.bis_community_banned', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bis_locked_account', full_name='CMsgClientIsLimitedAccount.bis_locked_account', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bis_limited_account_allowed_to_invite_friends', full_name='CMsgClientIsLimitedAccount.bis_limited_account_allowed_to_invite_friends', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3469,
  serialized_end=3639,
)


_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND = _descriptor.Descriptor(
  name='StatsToSend',
  full_name='CMsgClientRequestedClientStats.StatsToSend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_stat', full_name='CMsgClientRequestedClientStats.StatsToSend.client_stat', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_aggregate_method', full_name='CMsgClientRequestedClientStats.StatsToSend.stat_aggregate_method', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3744,
  serialized_end=3809,
)

_CMSGCLIENTREQUESTEDCLIENTSTATS = _descriptor.Descriptor(
  name='CMsgClientRequestedClientStats',
  full_name='CMsgClientRequestedClientStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_to_send', full_name='CMsgClientRequestedClientStats.stats_to_send', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3642,
  serialized_end=3809,
)


_CMSGCLIENTSTAT2_STATDETAIL = _descriptor.Descriptor(
  name='StatDetail',
  full_name='CMsgClientStat2.StatDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_stat', full_name='CMsgClientStat2.StatDetail.client_stat', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ll_value', full_name='CMsgClientStat2.StatDetail.ll_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_of_day', full_name='CMsgClientStat2.StatDetail.time_of_day', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientStat2.StatDetail.cell_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientStat2.StatDetail.depot_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientStat2.StatDetail.app_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=4004,
)

_CMSGCLIENTSTAT2 = _descriptor.Descriptor(
  name='CMsgClientStat2',
  full_name='CMsgClientStat2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_detail', full_name='CMsgClientStat2.stat_detail', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTAT2_STATDETAIL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3812,
  serialized_end=4004,
)


_CMSGCLIENTINVITETOGAME = _descriptor.Descriptor(
  name='CMsgClientInviteToGame',
  full_name='CMsgClientInviteToGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientInviteToGame.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientInviteToGame.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CMsgClientInviteToGame.connect_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_play', full_name='CMsgClientInviteToGame.remote_play', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4006,
  serialized_end=4120,
)


_CMSGCLIENTCHATINVITE = _descriptor.Descriptor(
  name='CMsgClientChatInvite',
  full_name='CMsgClientChatInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_invited', full_name='CMsgClientChatInvite.steam_id_invited', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_chat', full_name='CMsgClientChatInvite.steam_id_chat', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_patron', full_name='CMsgClientChatInvite.steam_id_patron', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatroom_type', full_name='CMsgClientChatInvite.chatroom_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_friend_chat', full_name='CMsgClientChatInvite.steam_id_friend_chat', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_name', full_name='CMsgClientChatInvite.chat_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientChatInvite.game_id', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4308,
)


_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON = _descriptor.Descriptor(
  name='Stats_Logon',
  full_name='CMsgClientConnectionStats.Stats_Logon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connect_attempts', full_name='CMsgClientConnectionStats.Stats_Logon.connect_attempts', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_successes', full_name='CMsgClientConnectionStats.Stats_Logon.connect_successes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_failures', full_name='CMsgClientConnectionStats.Stats_Logon.connect_failures', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connections_dropped', full_name='CMsgClientConnectionStats.Stats_Logon.connections_dropped', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_running', full_name='CMsgClientConnectionStats.Stats_Logon.seconds_running', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msec_tologonthistime', full_name='CMsgClientConnectionStats.Stats_Logon.msec_tologonthistime', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_bad_cms', full_name='CMsgClientConnectionStats.Stats_Logon.count_bad_cms', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_udp_connectivity', full_name='CMsgClientConnectionStats.Stats_Logon.no_udp_connectivity', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_tcp_connectivity', full_name='CMsgClientConnectionStats.Stats_Logon.no_tcp_connectivity', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_websocket_443_connectivity', full_name='CMsgClientConnectionStats.Stats_Logon.no_websocket_443_connectivity', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_websocket_non_443_connectivity', full_name='CMsgClientConnectionStats.Stats_Logon.no_websocket_non_443_connectivity', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4463,
  serialized_end=4802,
)

_CMSGCLIENTCONNECTIONSTATS_STATS_UDP = _descriptor.Descriptor(
  name='Stats_UDP',
  full_name='CMsgClientConnectionStats.Stats_UDP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkts_sent', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_sent', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='CMsgClientConnectionStats.Stats_UDP.bytes_sent', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkts_recv', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_recv', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkts_processed', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_processed', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_recv', full_name='CMsgClientConnectionStats.Stats_UDP.bytes_recv', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4804,
  serialized_end=4917,
)

_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN = _descriptor.Descriptor(
  name='Stats_VConn',
  full_name='CMsgClientConnectionStats.Stats_VConn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections_udp', full_name='CMsgClientConnectionStats.Stats_VConn.connections_udp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connections_tcp', full_name='CMsgClientConnectionStats.Stats_VConn.connections_tcp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_udp', full_name='CMsgClientConnectionStats.Stats_VConn.stats_udp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkts_abandoned', full_name='CMsgClientConnectionStats.Stats_VConn.pkts_abandoned', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conn_req_received', full_name='CMsgClientConnectionStats.Stats_VConn.conn_req_received', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkts_resent', full_name='CMsgClientConnectionStats.Stats_VConn.pkts_resent', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgs_sent', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_sent', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgs_sent_failed', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_sent_failed', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgs_recv', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_recv', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datagrams_sent', full_name='CMsgClientConnectionStats.Stats_VConn.datagrams_sent', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datagrams_recv', full_name='CMsgClientConnectionStats.Stats_VConn.datagrams_recv', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bad_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.bad_pkts_recv', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown_conn_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.unknown_conn_pkts_recv', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missed_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.missed_pkts_recv', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dup_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.dup_pkts_recv', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_connect_challenges', full_name='CMsgClientConnectionStats.Stats_VConn.failed_connect_challenges', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='micro_sec_avg_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_avg_latency', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='micro_sec_min_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_min_latency', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='micro_sec_max_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_max_latency', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mem_pool_msg_in_use', full_name='CMsgClientConnectionStats.Stats_VConn.mem_pool_msg_in_use', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4920,
  serialized_end=5485,
)

_CMSGCLIENTCONNECTIONSTATS = _descriptor.Descriptor(
  name='CMsgClientConnectionStats',
  full_name='CMsgClientConnectionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_logon', full_name='CMsgClientConnectionStats.stats_logon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_vconn', full_name='CMsgClientConnectionStats.stats_vconn', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON, _CMSGCLIENTCONNECTIONSTATS_STATS_UDP, _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4311,
  serialized_end=5485,
)


_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE = _descriptor.Descriptor(
  name='Server_Types_Available',
  full_name='CMsgClientServersAvailable.Server_Types_Available',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='CMsgClientServersAvailable.Server_Types_Available.server', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changed', full_name='CMsgClientServersAvailable.Server_Types_Available.changed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5641,
  serialized_end=5698,
)

_CMSGCLIENTSERVERSAVAILABLE = _descriptor.Descriptor(
  name='CMsgClientServersAvailable',
  full_name='CMsgClientServersAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_types_available', full_name='CMsgClientServersAvailable.server_types_available', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_type_for_auth_services', full_name='CMsgClientServersAvailable.server_type_for_auth_services', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5488,
  serialized_end=5698,
)


_CMSGCLIENTREPORTOVERLAYDETOURFAILURE = _descriptor.Descriptor(
  name='CMsgClientReportOverlayDetourFailure',
  full_name='CMsgClientReportOverlayDetourFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure_strings', full_name='CMsgClientReportOverlayDetourFailure.failure_strings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5700,
  serialized_end=5763,
)


_CMSGCLIENTREQUESTENCRYPTEDAPPTICKET = _descriptor.Descriptor(
  name='CMsgClientRequestEncryptedAppTicket',
  full_name='CMsgClientRequestEncryptedAppTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientRequestEncryptedAppTicket.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='CMsgClientRequestEncryptedAppTicket.userdata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5765,
  serialized_end=5836,
)


_CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestEncryptedAppTicketResponse',
  full_name='CMsgClientRequestEncryptedAppTicketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientRequestEncryptedAppTicketResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRequestEncryptedAppTicketResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypted_app_ticket', full_name='CMsgClientRequestEncryptedAppTicketResponse.encrypted_app_ticket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5839,
  serialized_end=5971,
)


_CMSGCLIENTWALLETINFOUPDATE = _descriptor.Descriptor(
  name='CMsgClientWalletInfoUpdate',
  full_name='CMsgClientWalletInfoUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_wallet', full_name='CMsgClientWalletInfoUpdate.has_wallet', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='CMsgClientWalletInfoUpdate.balance', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgClientWalletInfoUpdate.currency', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_delayed', full_name='CMsgClientWalletInfoUpdate.balance_delayed', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance64', full_name='CMsgClientWalletInfoUpdate.balance64', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\240\266\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance64_delayed', full_name='CMsgClientWalletInfoUpdate.balance64_delayed', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\240\266\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realm', full_name='CMsgClientWalletInfoUpdate.realm', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5974,
  serialized_end=6155,
)


_CMSGCLIENTAMGETCLANOFFICERS = _descriptor.Descriptor(
  name='CMsgClientAMGetClanOfficers',
  full_name='CMsgClientAMGetClanOfficers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientAMGetClanOfficers.steamid_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6157,
  serialized_end=6208,
)


_CMSGCLIENTAMGETCLANOFFICERSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAMGetClanOfficersResponse',
  full_name='CMsgClientAMGetClanOfficersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAMGetClanOfficersResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientAMGetClanOfficersResponse.steamid_clan', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='officer_count', full_name='CMsgClientAMGetClanOfficersResponse.officer_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6210,
  serialized_end=6312,
)


_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE = _descriptor.Descriptor(
  name='IdInstance',
  full_name='CMsgClientAMGetPersonaNameHistory.IdInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientAMGetPersonaNameHistory.IdInstance.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6430,
  serialized_end=6459,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORY = _descriptor.Descriptor(
  name='CMsgClientAMGetPersonaNameHistory',
  full_name='CMsgClientAMGetPersonaNameHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_count', full_name='CMsgClientAMGetPersonaNameHistory.id_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Ids', full_name='CMsgClientAMGetPersonaNameHistory.Ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6315,
  serialized_end=6459,
)


_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE = _descriptor.Descriptor(
  name='NameInstance',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_since', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance.name_since', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6737,
  serialized_end=6785,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE = _descriptor.Descriptor(
  name='NameTableInstance',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.names', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6589,
  serialized_end=6785,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAMGetPersonaNameHistoryResponse',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='CMsgClientAMGetPersonaNameHistoryResponse.responses', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6462,
  serialized_end=6785,
)


_CMSGCLIENTDEREGISTERWITHSERVER = _descriptor.Descriptor(
  name='CMsgClientDeregisterWithServer',
  full_name='CMsgClientDeregisterWithServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eservertype', full_name='CMsgClientDeregisterWithServer.eservertype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientDeregisterWithServer.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6787,
  serialized_end=6856,
)


_CMSGCLIENTCLANSTATE_NAMEINFO = _descriptor.Descriptor(
  name='NameInfo',
  full_name='CMsgClientClanState.NameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clan_name', full_name='CMsgClientClanState.NameInfo.clan_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_avatar', full_name='CMsgClientClanState.NameInfo.sha_avatar', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7158,
  serialized_end=7207,
)

_CMSGCLIENTCLANSTATE_USERCOUNTS = _descriptor.Descriptor(
  name='UserCounts',
  full_name='CMsgClientClanState.UserCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientClanState.UserCounts.members', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='CMsgClientClanState.UserCounts.online', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatting', full_name='CMsgClientClanState.UserCounts.chatting', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_game', full_name='CMsgClientClanState.UserCounts.in_game', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_room_members', full_name='CMsgClientClanState.UserCounts.chat_room_members', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7209,
  serialized_end=7316,
)

_CMSGCLIENTCLANSTATE_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='CMsgClientClanState.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMsgClientClanState.Event.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_time', full_name='CMsgClientClanState.Event.event_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CMsgClientClanState.Event.headline', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientClanState.Event.game_id', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='just_posted', full_name='CMsgClientClanState.Event.just_posted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7318,
  serialized_end=7414,
)

_CMSGCLIENTCLANSTATE = _descriptor.Descriptor(
  name='CMsgClientClanState',
  full_name='CMsgClientClanState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientClanState.steamid_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clan_account_flags', full_name='CMsgClientClanState.clan_account_flags', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_info', full_name='CMsgClientClanState.name_info', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_counts', full_name='CMsgClientClanState.user_counts', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='CMsgClientClanState.events', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcements', full_name='CMsgClientClanState.announcements', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_room_private', full_name='CMsgClientClanState.chat_room_private', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCLANSTATE_NAMEINFO, _CMSGCLIENTCLANSTATE_USERCOUNTS, _CMSGCLIENTCLANSTATE_EVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6859,
  serialized_end=7414,
)

_CMSGCLIENTGAMESPLAYED_GAMEPLAYED.fields_by_name['game_ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTGAMESPLAYED_GAMEPLAYED.containing_type = _CMSGCLIENTGAMESPLAYED
_CMSGCLIENTGAMESPLAYED.fields_by_name['games_played'].message_type = _CMSGCLIENTGAMESPLAYED_GAMEPLAYED
_CMSGCLIENTAUTHLIST.fields_by_name['tickets'].message_type = steammessages__base__pb2._CMSGAUTHTICKET
_CMSGCLIENTLICENSELIST_LICENSE.containing_type = _CMSGCLIENTLICENSELIST
_CMSGCLIENTLICENSELIST.fields_by_name['licenses'].message_type = _CMSGCLIENTLICENSELIST_LICENSE
_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND.containing_type = _CMSGCLIENTREQUESTEDCLIENTSTATS
_CMSGCLIENTREQUESTEDCLIENTSTATS.fields_by_name['stats_to_send'].message_type = _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND
_CMSGCLIENTSTAT2_STATDETAIL.containing_type = _CMSGCLIENTSTAT2
_CMSGCLIENTSTAT2.fields_by_name['stat_detail'].message_type = _CMSGCLIENTSTAT2_STATDETAIL
_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS_STATS_UDP.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN.fields_by_name['stats_udp'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_UDP
_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS.fields_by_name['stats_logon'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON
_CMSGCLIENTCONNECTIONSTATS.fields_by_name['stats_vconn'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN
_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE.containing_type = _CMSGCLIENTSERVERSAVAILABLE
_CMSGCLIENTSERVERSAVAILABLE.fields_by_name['server_types_available'].message_type = _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE
_CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE.fields_by_name['encrypted_app_ticket'].message_type = encrypted__app__ticket__pb2._ENCRYPTEDAPPTICKET
_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORY
_CMSGCLIENTAMGETPERSONANAMEHISTORY.fields_by_name['Ids'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE.fields_by_name['names'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE.fields_by_name['responses'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE
_CMSGCLIENTCLANSTATE_NAMEINFO.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE_USERCOUNTS.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE_EVENT.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE.fields_by_name['name_info'].message_type = _CMSGCLIENTCLANSTATE_NAMEINFO
_CMSGCLIENTCLANSTATE.fields_by_name['user_counts'].message_type = _CMSGCLIENTCLANSTATE_USERCOUNTS
_CMSGCLIENTCLANSTATE.fields_by_name['events'].message_type = _CMSGCLIENTCLANSTATE_EVENT
_CMSGCLIENTCLANSTATE.fields_by_name['announcements'].message_type = _CMSGCLIENTCLANSTATE_EVENT
DESCRIPTOR.message_types_by_name['CMsgClientRegisterAuthTicketWithCM'] = _CMSGCLIENTREGISTERAUTHTICKETWITHCM
DESCRIPTOR.message_types_by_name['CMsgClientTicketAuthComplete'] = _CMSGCLIENTTICKETAUTHCOMPLETE
DESCRIPTOR.message_types_by_name['CMsgClientCMList'] = _CMSGCLIENTCMLIST
DESCRIPTOR.message_types_by_name['CMsgClientP2PConnectionInfo'] = _CMSGCLIENTP2PCONNECTIONINFO
DESCRIPTOR.message_types_by_name['CMsgClientP2PConnectionFailInfo'] = _CMSGCLIENTP2PCONNECTIONFAILINFO
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingCertRequest'] = _CMSGCLIENTNETWORKINGCERTREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingCertReply'] = _CMSGCLIENTNETWORKINGCERTREPLY
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingMobileCertRequest'] = _CMSGCLIENTNETWORKINGMOBILECERTREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingMobileCertReply'] = _CMSGCLIENTNETWORKINGMOBILECERTREPLY
DESCRIPTOR.message_types_by_name['CMsgClientGetAppOwnershipTicket'] = _CMSGCLIENTGETAPPOWNERSHIPTICKET
DESCRIPTOR.message_types_by_name['CMsgClientGetAppOwnershipTicketResponse'] = _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSessionToken'] = _CMSGCLIENTSESSIONTOKEN
DESCRIPTOR.message_types_by_name['CMsgClientGameConnectTokens'] = _CMSGCLIENTGAMECONNECTTOKENS
DESCRIPTOR.message_types_by_name['CMsgClientGamesPlayed'] = _CMSGCLIENTGAMESPLAYED
DESCRIPTOR.message_types_by_name['CMsgGSApprove'] = _CMSGGSAPPROVE
DESCRIPTOR.message_types_by_name['CMsgGSDeny'] = _CMSGGSDENY
DESCRIPTOR.message_types_by_name['CMsgGSKick'] = _CMSGGSKICK
DESCRIPTOR.message_types_by_name['CMsgClientAuthList'] = _CMSGCLIENTAUTHLIST
DESCRIPTOR.message_types_by_name['CMsgClientAuthListAck'] = _CMSGCLIENTAUTHLISTACK
DESCRIPTOR.message_types_by_name['CMsgClientLicenseList'] = _CMSGCLIENTLICENSELIST
DESCRIPTOR.message_types_by_name['CMsgClientIsLimitedAccount'] = _CMSGCLIENTISLIMITEDACCOUNT
DESCRIPTOR.message_types_by_name['CMsgClientRequestedClientStats'] = _CMSGCLIENTREQUESTEDCLIENTSTATS
DESCRIPTOR.message_types_by_name['CMsgClientStat2'] = _CMSGCLIENTSTAT2
DESCRIPTOR.message_types_by_name['CMsgClientInviteToGame'] = _CMSGCLIENTINVITETOGAME
DESCRIPTOR.message_types_by_name['CMsgClientChatInvite'] = _CMSGCLIENTCHATINVITE
DESCRIPTOR.message_types_by_name['CMsgClientConnectionStats'] = _CMSGCLIENTCONNECTIONSTATS
DESCRIPTOR.message_types_by_name['CMsgClientServersAvailable'] = _CMSGCLIENTSERVERSAVAILABLE
DESCRIPTOR.message_types_by_name['CMsgClientReportOverlayDetourFailure'] = _CMSGCLIENTREPORTOVERLAYDETOURFAILURE
DESCRIPTOR.message_types_by_name['CMsgClientRequestEncryptedAppTicket'] = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET
DESCRIPTOR.message_types_by_name['CMsgClientRequestEncryptedAppTicketResponse'] = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientWalletInfoUpdate'] = _CMSGCLIENTWALLETINFOUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientAMGetClanOfficers'] = _CMSGCLIENTAMGETCLANOFFICERS
DESCRIPTOR.message_types_by_name['CMsgClientAMGetClanOfficersResponse'] = _CMSGCLIENTAMGETCLANOFFICERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAMGetPersonaNameHistory'] = _CMSGCLIENTAMGETPERSONANAMEHISTORY
DESCRIPTOR.message_types_by_name['CMsgClientAMGetPersonaNameHistoryResponse'] = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientDeregisterWithServer'] = _CMSGCLIENTDEREGISTERWITHSERVER
DESCRIPTOR.message_types_by_name['CMsgClientClanState'] = _CMSGCLIENTCLANSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientRegisterAuthTicketWithCM = _reflection.GeneratedProtocolMessageType('CMsgClientRegisterAuthTicketWithCM', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREGISTERAUTHTICKETWITHCM,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRegisterAuthTicketWithCM)
  })
_sym_db.RegisterMessage(CMsgClientRegisterAuthTicketWithCM)

CMsgClientTicketAuthComplete = _reflection.GeneratedProtocolMessageType('CMsgClientTicketAuthComplete', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTTICKETAUTHCOMPLETE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientTicketAuthComplete)
  })
_sym_db.RegisterMessage(CMsgClientTicketAuthComplete)

CMsgClientCMList = _reflection.GeneratedProtocolMessageType('CMsgClientCMList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCMLIST,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCMList)
  })
_sym_db.RegisterMessage(CMsgClientCMList)

CMsgClientP2PConnectionInfo = _reflection.GeneratedProtocolMessageType('CMsgClientP2PConnectionInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTP2PCONNECTIONINFO,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientP2PConnectionInfo)
  })
_sym_db.RegisterMessage(CMsgClientP2PConnectionInfo)

CMsgClientP2PConnectionFailInfo = _reflection.GeneratedProtocolMessageType('CMsgClientP2PConnectionFailInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTP2PCONNECTIONFAILINFO,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientP2PConnectionFailInfo)
  })
_sym_db.RegisterMessage(CMsgClientP2PConnectionFailInfo)

CMsgClientNetworkingCertRequest = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingCertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTNETWORKINGCERTREQUEST,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingCertRequest)
  })
_sym_db.RegisterMessage(CMsgClientNetworkingCertRequest)

CMsgClientNetworkingCertReply = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingCertReply', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTNETWORKINGCERTREPLY,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingCertReply)
  })
_sym_db.RegisterMessage(CMsgClientNetworkingCertReply)

CMsgClientNetworkingMobileCertRequest = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingMobileCertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTNETWORKINGMOBILECERTREQUEST,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingMobileCertRequest)
  })
_sym_db.RegisterMessage(CMsgClientNetworkingMobileCertRequest)

CMsgClientNetworkingMobileCertReply = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingMobileCertReply', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTNETWORKINGMOBILECERTREPLY,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingMobileCertReply)
  })
_sym_db.RegisterMessage(CMsgClientNetworkingMobileCertReply)

CMsgClientGetAppOwnershipTicket = _reflection.GeneratedProtocolMessageType('CMsgClientGetAppOwnershipTicket', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETAPPOWNERSHIPTICKET,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAppOwnershipTicket)
  })
_sym_db.RegisterMessage(CMsgClientGetAppOwnershipTicket)

CMsgClientGetAppOwnershipTicketResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetAppOwnershipTicketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAppOwnershipTicketResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetAppOwnershipTicketResponse)

CMsgClientSessionToken = _reflection.GeneratedProtocolMessageType('CMsgClientSessionToken', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSESSIONTOKEN,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSessionToken)
  })
_sym_db.RegisterMessage(CMsgClientSessionToken)

CMsgClientGameConnectTokens = _reflection.GeneratedProtocolMessageType('CMsgClientGameConnectTokens', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGAMECONNECTTOKENS,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGameConnectTokens)
  })
_sym_db.RegisterMessage(CMsgClientGameConnectTokens)

CMsgClientGamesPlayed = _reflection.GeneratedProtocolMessageType('CMsgClientGamesPlayed', (_message.Message,), {

  'GamePlayed' : _reflection.GeneratedProtocolMessageType('GamePlayed', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGAMESPLAYED_GAMEPLAYED,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGamesPlayed.GamePlayed)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGAMESPLAYED,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGamesPlayed)
  })
_sym_db.RegisterMessage(CMsgClientGamesPlayed)
_sym_db.RegisterMessage(CMsgClientGamesPlayed.GamePlayed)

CMsgGSApprove = _reflection.GeneratedProtocolMessageType('CMsgGSApprove', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSAPPROVE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSApprove)
  })
_sym_db.RegisterMessage(CMsgGSApprove)

CMsgGSDeny = _reflection.GeneratedProtocolMessageType('CMsgGSDeny', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSDENY,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSDeny)
  })
_sym_db.RegisterMessage(CMsgGSDeny)

CMsgGSKick = _reflection.GeneratedProtocolMessageType('CMsgGSKick', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGSKICK,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSKick)
  })
_sym_db.RegisterMessage(CMsgGSKick)

CMsgClientAuthList = _reflection.GeneratedProtocolMessageType('CMsgClientAuthList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAUTHLIST,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthList)
  })
_sym_db.RegisterMessage(CMsgClientAuthList)

CMsgClientAuthListAck = _reflection.GeneratedProtocolMessageType('CMsgClientAuthListAck', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAUTHLISTACK,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthListAck)
  })
_sym_db.RegisterMessage(CMsgClientAuthListAck)

CMsgClientLicenseList = _reflection.GeneratedProtocolMessageType('CMsgClientLicenseList', (_message.Message,), {

  'License' : _reflection.GeneratedProtocolMessageType('License', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTLICENSELIST_LICENSE,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientLicenseList.License)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTLICENSELIST,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLicenseList)
  })
_sym_db.RegisterMessage(CMsgClientLicenseList)
_sym_db.RegisterMessage(CMsgClientLicenseList.License)

CMsgClientIsLimitedAccount = _reflection.GeneratedProtocolMessageType('CMsgClientIsLimitedAccount', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTISLIMITEDACCOUNT,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientIsLimitedAccount)
  })
_sym_db.RegisterMessage(CMsgClientIsLimitedAccount)

CMsgClientRequestedClientStats = _reflection.GeneratedProtocolMessageType('CMsgClientRequestedClientStats', (_message.Message,), {

  'StatsToSend' : _reflection.GeneratedProtocolMessageType('StatsToSend', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientRequestedClientStats.StatsToSend)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTREQUESTEDCLIENTSTATS,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestedClientStats)
  })
_sym_db.RegisterMessage(CMsgClientRequestedClientStats)
_sym_db.RegisterMessage(CMsgClientRequestedClientStats.StatsToSend)

CMsgClientStat2 = _reflection.GeneratedProtocolMessageType('CMsgClientStat2', (_message.Message,), {

  'StatDetail' : _reflection.GeneratedProtocolMessageType('StatDetail', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSTAT2_STATDETAIL,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStat2.StatDetail)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSTAT2,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStat2)
  })
_sym_db.RegisterMessage(CMsgClientStat2)
_sym_db.RegisterMessage(CMsgClientStat2.StatDetail)

CMsgClientInviteToGame = _reflection.GeneratedProtocolMessageType('CMsgClientInviteToGame', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTINVITETOGAME,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInviteToGame)
  })
_sym_db.RegisterMessage(CMsgClientInviteToGame)

CMsgClientChatInvite = _reflection.GeneratedProtocolMessageType('CMsgClientChatInvite', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTCHATINVITE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChatInvite)
  })
_sym_db.RegisterMessage(CMsgClientChatInvite)

CMsgClientConnectionStats = _reflection.GeneratedProtocolMessageType('CMsgClientConnectionStats', (_message.Message,), {

  'Stats_Logon' : _reflection.GeneratedProtocolMessageType('Stats_Logon', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_Logon)
    })
  ,

  'Stats_UDP' : _reflection.GeneratedProtocolMessageType('Stats_UDP', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCONNECTIONSTATS_STATS_UDP,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_UDP)
    })
  ,

  'Stats_VConn' : _reflection.GeneratedProtocolMessageType('Stats_VConn', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_VConn)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTCONNECTIONSTATS,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats)
  })
_sym_db.RegisterMessage(CMsgClientConnectionStats)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_Logon)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_UDP)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_VConn)

CMsgClientServersAvailable = _reflection.GeneratedProtocolMessageType('CMsgClientServersAvailable', (_message.Message,), {

  'Server_Types_Available' : _reflection.GeneratedProtocolMessageType('Server_Types_Available', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientServersAvailable.Server_Types_Available)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSERVERSAVAILABLE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServersAvailable)
  })
_sym_db.RegisterMessage(CMsgClientServersAvailable)
_sym_db.RegisterMessage(CMsgClientServersAvailable.Server_Types_Available)

CMsgClientReportOverlayDetourFailure = _reflection.GeneratedProtocolMessageType('CMsgClientReportOverlayDetourFailure', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREPORTOVERLAYDETOURFAILURE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientReportOverlayDetourFailure)
  })
_sym_db.RegisterMessage(CMsgClientReportOverlayDetourFailure)

CMsgClientRequestEncryptedAppTicket = _reflection.GeneratedProtocolMessageType('CMsgClientRequestEncryptedAppTicket', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestEncryptedAppTicket)
  })
_sym_db.RegisterMessage(CMsgClientRequestEncryptedAppTicket)

CMsgClientRequestEncryptedAppTicketResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestEncryptedAppTicketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestEncryptedAppTicketResponse)
  })
_sym_db.RegisterMessage(CMsgClientRequestEncryptedAppTicketResponse)

CMsgClientWalletInfoUpdate = _reflection.GeneratedProtocolMessageType('CMsgClientWalletInfoUpdate', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTWALLETINFOUPDATE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWalletInfoUpdate)
  })
_sym_db.RegisterMessage(CMsgClientWalletInfoUpdate)

CMsgClientAMGetClanOfficers = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetClanOfficers', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAMGETCLANOFFICERS,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetClanOfficers)
  })
_sym_db.RegisterMessage(CMsgClientAMGetClanOfficers)

CMsgClientAMGetClanOfficersResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetClanOfficersResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTAMGETCLANOFFICERSRESPONSE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetClanOfficersResponse)
  })
_sym_db.RegisterMessage(CMsgClientAMGetClanOfficersResponse)

CMsgClientAMGetPersonaNameHistory = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetPersonaNameHistory', (_message.Message,), {

  'IdInstance' : _reflection.GeneratedProtocolMessageType('IdInstance', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistory.IdInstance)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTAMGETPERSONANAMEHISTORY,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistory)
  })
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistory)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistory.IdInstance)

CMsgClientAMGetPersonaNameHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetPersonaNameHistoryResponse', (_message.Message,), {

  'NameTableInstance' : _reflection.GeneratedProtocolMessageType('NameTableInstance', (_message.Message,), {

    'NameInstance' : _reflection.GeneratedProtocolMessageType('NameInstance', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE,
      '__module__' : 'steammessages_clientserver_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance)
      })
    ,
    'DESCRIPTOR' : _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse)
  })
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance)

CMsgClientDeregisterWithServer = _reflection.GeneratedProtocolMessageType('CMsgClientDeregisterWithServer', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTDEREGISTERWITHSERVER,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeregisterWithServer)
  })
_sym_db.RegisterMessage(CMsgClientDeregisterWithServer)

CMsgClientClanState = _reflection.GeneratedProtocolMessageType('CMsgClientClanState', (_message.Message,), {

  'NameInfo' : _reflection.GeneratedProtocolMessageType('NameInfo', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCLANSTATE_NAMEINFO,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.NameInfo)
    })
  ,

  'UserCounts' : _reflection.GeneratedProtocolMessageType('UserCounts', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCLANSTATE_USERCOUNTS,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.UserCounts)
    })
  ,

  'Event' : _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTCLANSTATE_EVENT,
    '__module__' : 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.Event)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTCLANSTATE,
  '__module__' : 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientClanState)
  })
_sym_db.RegisterMessage(CMsgClientClanState)
_sym_db.RegisterMessage(CMsgClientClanState.NameInfo)
_sym_db.RegisterMessage(CMsgClientClanState.UserCounts)
_sym_db.RegisterMessage(CMsgClientClanState.Event)


DESCRIPTOR._options = None
_CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64']._options = None
_CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64_delayed']._options = None
# @@protoc_insertion_point(module_scope)
